This module is a re-creation of *random-cat*. It isn't working! It displays HTTP 403 error! **DO NOT DOWNLOAD IT!**

Download this instead. This module same uses Cat API. (https://thecatapi.com)
>Installation

Install through *pip*.
```
pip install randomcatimage
```
>Usage

The module has just one function **getCat()** with one argument.

*mime*:
- png
- jpg
- gif
>Demo
```
import randomcatimage as cat
cat.getCat('png')
```
The function return the image link.